@@ -7,7 +7,7 @@
 #  define KSANE_NO_EXPORT
 #else
 #  ifndef KSANE_EXPORT
-#    ifdef KSaneWidgets_EXPORTS
+#    ifdef KF5Sane_EXPORTS
         /* We are building this library */
 #      define KSANE_EXPORT __attribute__((visibility("default")))
 #    else
@@ -61,7 +61,7 @@
 #define KSANE_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KSANE_NO_DEPRECATED
-#  define KSANE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x180500
+#  define KSANE_DISABLE_DEPRECATED_BEFORE_AND_AT 0x170803
 #endif
 #ifdef KSANE_NO_DEPRECATED_WARNINGS
 #  define KSANE_DEPRECATED_WARNINGS_SINCE 0
@@ -71,7 +71,7 @@
 #  ifdef KSANE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KSANE_DEPRECATED_WARNINGS_SINCE KSANE_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KSANE_DEPRECATED_WARNINGS_SINCE 0x180500
+#    define KSANE_DEPRECATED_WARNINGS_SINCE 0x170803
 #  endif
 #endif
 
